summaryrefslogtreecommitdiff
path: root/automation/source/server/profiler.cxx
diff options
context:
space:
mode:
Diffstat (limited to 'automation/source/server/profiler.cxx')
-rw-r--r--automation/source/server/profiler.cxx40
1 files changed, 20 insertions, 20 deletions
diff --git a/automation/source/server/profiler.cxx b/automation/source/server/profiler.cxx
index 1f9a63c18bd9..c11ddce1014a 100644
--- a/automation/source/server/profiler.cxx
+++ b/automation/source/server/profiler.cxx
@@ -43,10 +43,10 @@
TTProfiler::TTProfiler()
: mpStart( NULL )
, mpEnd( NULL )
-, bIsProfileIntervalStarted( FALSE )
-, bIsProfilingPerCommand( FALSE )
-, bIsPartitioning( FALSE )
-, bIsAutoProfiling( FALSE )
+, bIsProfileIntervalStarted( sal_False )
+, bIsProfilingPerCommand( sal_False )
+, bIsPartitioning( sal_False )
+, bIsAutoProfiling( sal_False )
, pSysDepStatic( NULL )
{
InitSysdepProfiler();
@@ -94,13 +94,13 @@ String TTProfiler::GetProfileHeader()
}
-void TTProfiler::StartProfileInterval( BOOL bReadAnyway )
+void TTProfiler::StartProfileInterval( sal_Bool bReadAnyway )
{
if ( !bIsProfileIntervalStarted || bReadAnyway )
{
GetProfileSnapshot( mpStart );
GetSysdepProfileSnapshot( mpStart->pSysdepProfileSnapshot, PROFILE_START );
- bIsProfileIntervalStarted = TRUE;
+ bIsProfileIntervalStarted = sal_True;
}
}
@@ -108,10 +108,10 @@ String TTProfiler::GetProfileLine( ProfileSnapshot *pStart, ProfileSnapshot *pEn
{
String aProfileString;
- aProfileString += Pad(GetpApp()->GetAppLocaleDataWrapper().getDuration( DIFF( pStart, pEnd, aTime) , TRUE, TRUE ), 12);
+ aProfileString += Pad(GetpApp()->GetAppLocaleDataWrapper().getDuration( DIFF( pStart, pEnd, aTime) , sal_True, sal_True ), 12);
- ULONG nProcessTicks = DIFF( pStart, pEnd, nProcessTicks );
- ULONG nSystemTicks = DIFF( pStart, pEnd, nSystemTicks );
+ sal_uLong nProcessTicks = DIFF( pStart, pEnd, nProcessTicks );
+ sal_uLong nSystemTicks = DIFF( pStart, pEnd, nSystemTicks );
if ( nSystemTicks )
{
aProfileString += Pad(UniString::CreateFromInt32( (100 * nProcessTicks) / nSystemTicks ), 11);
@@ -146,7 +146,7 @@ void TTProfiler::EndProfileInterval()
{
GetProfileSnapshot( mpEnd );
GetSysdepProfileSnapshot( mpEnd->pSysdepProfileSnapshot, PROFILE_END );
- bIsProfileIntervalStarted = FALSE;
+ bIsProfileIntervalStarted = sal_False;
}
@@ -160,32 +160,32 @@ void TTProfiler::GetProfileSnapshot( ProfileSnapshot *pProfileSnapshot )
void TTProfiler::StartProfilingPerCommand() // Jeden Befehl mitschneiden
{
- bIsProfilingPerCommand = TRUE;
+ bIsProfilingPerCommand = sal_True;
}
void TTProfiler::StopProfilingPerCommand()
{
- bIsProfilingPerCommand = FALSE;
+ bIsProfilingPerCommand = sal_False;
}
void TTProfiler::StartPartitioning()
{
- bIsPartitioning = TRUE;
+ bIsPartitioning = sal_True;
}
void TTProfiler::StopPartitioning()
{
- bIsPartitioning = TRUE;
+ bIsPartitioning = sal_True;
}
-ULONG TTProfiler::GetPartitioningTime()
+sal_uLong TTProfiler::GetPartitioningTime()
{
return DIFF( mpStart, mpEnd, nSystemTicks );
}
-void TTProfiler::StartAutoProfiling( ULONG nMSec )
+void TTProfiler::StartAutoProfiling( sal_uLong nMSec )
{
if ( !bIsAutoProfiling )
{
@@ -196,7 +196,7 @@ void TTProfiler::StartAutoProfiling( ULONG nMSec )
GetProfileSnapshot( pAutoStart );
GetSysdepProfileSnapshot( pAutoStart->pSysdepProfileSnapshot, PROFILE_START );
SetTimeout( nMSec );
- bIsAutoProfiling = TRUE;
+ bIsAutoProfiling = sal_True;
Start();
}
@@ -233,14 +233,14 @@ void TTProfiler::StopAutoProfiling()
if ( bIsAutoProfiling )
{
Stop();
- bIsAutoProfiling = FALSE;
+ bIsAutoProfiling = sal_False;
}
}
-//String TTProfiler::Hex( ULONG nNr )
-String TTProfiler::Dec( ULONG nNr )
+//String TTProfiler::Hex( sal_uLong nNr )
+String TTProfiler::Dec( sal_uLong nNr )
{
String aRet(UniString::CreateFromInt32(nNr));
if ( nNr < 100 )